net.c: Remove unnecessary crypto includes.
[paraslash.git] / write.h
diff --git a/write.h b/write.h
index 936d99c0a45cc1bcc166e97fbb4552d2545182ca..0044ae4f79d3cbde19d9d9dc5630bf048a6a6986 100644 (file)
--- a/write.h
+++ b/write.h
@@ -1,5 +1,5 @@
 /*
 /*
- * Copyright (C) 2006-2009 Andre Noll <maan@systemlinux.org>
+ * Copyright (C) 2006-2011 Andre Noll <maan@systemlinux.org>
  *
  * Licensed under the GPL v2. For licencing details see COPYING.
  */
  *
  * Licensed under the GPL v2. For licencing details see COPYING.
  */
@@ -36,21 +36,20 @@ struct writer {
        /**
         * The command line parser of the writer.
         *
        /**
         * The command line parser of the writer.
         *
* It should check whether the command line options given by \a options are
* valid.  On success, it should return a pointer to the writer-specific
* configuration data determined by \a options.  Note that this might be called
* more than once with different values of \a options.
         */
         */
-       void *(*parse_config)(const char *options);
-       void (*free_config)(void *conf);
+       void *(*parse_config_or_die)(const char *options);
        /**
        /**
-        * Open one instance of this writer.
+        * Dellocate all configuration resources.
         *
         *
-        * This function should perform any work necessary to write the incoming
-        * stream. To this aim, it may allocate its private data structure and store
-        * a pointer to that structure via the given writer_node parameter.
+        * This should free whatever was allocated by \ref parse_config_or_die().
         */
         */
-       int (*open)(struct writer_node *);
+       void (*free_config)(void *config);
        /**
         * Prepare the fd sets for select.
         *
@@ -36,21 +36,20 @@ struct writer {
         * The command line parser of the writer.
         *
-        * It should check whether the command line options given by \a options are
-        * valid.  On success, it should return a pointer to the writer-specific
-        * configuration data determined by \a options.  Note that this might be called
-        * more than once with different values of \a options.
+        * It should check whether the command line options given by \a options
+        * are valid and return a pointer to the writer-specific configuration
+        * data determined by \a options. This function must either succeed or
+        * call exit(). Note that parse_config_or_die() might be called more
+        * than once with different values of \a options. \sa \ref
+        * free_config().
         */
         */
        /**
         * Prepare the fd sets for select.
         *